Index: apps/confbridge/include/confbridge.h
===================================================================
--- apps/confbridge/include/confbridge.h	(revision 398920)
+++ apps/confbridge/include/confbridge.h	(working copy)
@@ -192,6 +192,7 @@
 
 struct bridge_profile {
 	char name[64];
+	char language[MAX_LANGUAGE];					  /*!< Language used for playback_chan */
 	char rec_file[PATH_MAX];
 	unsigned int flags;
 	unsigned int max_members;          /*!< The maximum number of participants allowed in the conference */
Index: apps/confbridge/conf_config_parser.c
===================================================================
--- apps/confbridge/conf_config_parser.c	(revision 398920)
+++ apps/confbridge/conf_config_parser.c	(working copy)
@@ -257,6 +257,12 @@
 						will be used.
 					</para></description>
 				</configOption>
+				<configOption name="language" default="en">
+					<synopsis>The language used for internal playback</synopsis>
+					<description><para>
+						Set confbridge-join and confbridge-leave correctly
+					</para></description>
+				</configOption>
 				<configOption name="mixing_interval">
 					<synopsis>Sets the internal mixing interval in milliseconds for the bridge</synopsis>
 					<description><para>
@@ -1934,6 +1940,7 @@
 	aco_option_register(&cfg_info, "record_file_append", ACO_EXACT, bridge_types, "yes", OPT_BOOLFLAG_T, 1, FLDSET(struct bridge_profile, flags), BRIDGE_OPT_RECORD_FILE_APPEND);
 	aco_option_register(&cfg_info, "max_members", ACO_EXACT, bridge_types, "0", OPT_UINT_T, 0, FLDSET(struct bridge_profile, max_members));
 	aco_option_register(&cfg_info, "record_file", ACO_EXACT, bridge_types, NULL, OPT_CHAR_ARRAY_T, 0, CHARFLDSET(struct bridge_profile, rec_file));
+	aco_option_register(&cfg_info, "language", ACO_EXACT, bridge_types, "en", OPT_CHAR_ARRAY_T, 0, CHARFLDSET(struct bridge_profile, language));
 	aco_option_register_custom(&cfg_info, "^sound_", ACO_REGEX, bridge_types, NULL, sound_option_handler, 0);
 	/* This option should only be used with the CONFBRIDGE dialplan function */
 	aco_option_register_custom(&cfg_info, "template", ACO_EXACT, bridge_types, NULL, bridge_template_handler, 0);
Index: apps/app_confbridge.c
===================================================================
--- apps/app_confbridge.c	(revision 398920)
+++ apps/app_confbridge.c	(working copy)
@@ -1339,6 +1339,13 @@
 		return -1;
 	}
 
+	if ( strcmp(conference->b_profile.language,"")) {
+		ast_channel_language_set(conference->playback_chan, conference->b_profile.language);
+		ast_log(LOG_WARNING, "Playback channel language is '%s'\n", conference->b_profile.language);
+	} else {
+		 ast_log(LOG_WARNING, "Playback channel language is using default");
+	}
+
 	ast_debug(1, "Created announcer channel '%s' to conference bridge '%s'\n",
 		ast_channel_name(conference->playback_chan), conference->name);
 	return 0;
